@@ -15,9 +15,4 @@
 #
 # ##### END GPL LICENSE BLOCK #####
 
-from . import daily_uses
-
-print("""Python module SeanBlend
-Owner: SeanBlend <https://github.com/SeanBlend>
-Contributors:
-    Sean Huang <https://github.com/SeanBlend>""")
\ No newline at end of file
+from . import math
\ No newline at end of file
